Index: includes/theme.inc
===================================================================
RCS file: /cvs/drupal/drupal/includes/theme.inc,v
retrieving revision 1.494
diff -u -p -r1.494 theme.inc
--- includes/theme.inc	6 Jun 2009 16:05:26 -0000	1.494
+++ includes/theme.inc	12 Jun 2009 08:39:21 -0000
@@ -1928,11 +1928,11 @@ function template_preprocess_page(&$vari
 
   // Set up layout variable.
   $variables['layout'] = 'none';
-  if (!empty($variables['left'])) {
-    $variables['layout'] = 'left';
+  if (!empty($variables['sidebar_first'])) {
+    $variables['layout'] = 'first';
   }
-  if (!empty($variables['right'])) {
-    $variables['layout'] = ($variables['layout'] == 'left') ? 'both' : 'right';
+  if (!empty($variables['sidebar_second'])) {
+    $variables['layout'] = ($variables['layout'] == 'first') ? 'both' : 'second';
   }
 
   // Construct page title
Index: includes/theme.maintenance.inc
===================================================================
RCS file: /cvs/drupal/drupal/includes/theme.maintenance.inc,v
retrieving revision 1.30
diff -u -p -r1.30 theme.maintenance.inc
--- includes/theme.maintenance.inc	6 Jun 2009 16:05:26 -0000	1.30
+++ includes/theme.maintenance.inc	12 Jun 2009 08:39:21 -0000
@@ -235,11 +235,11 @@ function template_preprocess_maintenance
 
   // Setup layout variable.
   $variables['layout'] = 'none';
-  if (!empty($variables['left'])) {
-    $variables['layout'] = 'left';
+  if (!empty($variables['sidebar_first'])) {
+    $variables['layout'] = 'first';
   }
-  if (!empty($variables['right'])) {
-    $variables['layout'] = ($variables['layout'] == 'left') ? 'both' : 'right';
+  if (!empty($variables['sidebar_second'])) {
+    $variables['layout'] = ($variables['layout'] == 'first') ? 'both' : 'second';
   }
 
   // Construct page title
Index: modules/block/block.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/block/block.module,v
retrieving revision 1.344
diff -u -p -r1.344 block.module
--- modules/block/block.module	8 Jun 2009 09:23:50 -0000	1.344
+++ modules/block/block.module	12 Jun 2009 08:39:21 -0000
@@ -240,8 +240,8 @@ function block_page_alter($page) {
 
   // Load all region content assigned via blocks.
   foreach (array_keys($regions) as $region) {
-    // Prevent left and right regions from rendering blocks when 'show_blocks' == FALSE.
-    if (!empty($page['#show_blocks']) || ($region != 'left' && $region != 'right')) {
+    // Prevent sidebar regions from rendering blocks when 'show_blocks' == FALSE.
+    if (!empty($page['#show_blocks']) || (strpos($region, 'sidebar_') !== 0)) {
       // Assign blocks to region.
       if ($blocks = block_get_blocks_by_region($region)) {
         $page[$region]['blocks'] = $blocks;
Index: modules/system/system.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/system/system.module,v
retrieving revision 1.711
diff -u -p -r1.711 system.module
--- modules/system/system.module	11 Jun 2009 04:36:22 -0000	1.711
+++ modules/system/system.module	12 Jun 2009 08:39:22 -0000
@@ -1324,8 +1324,8 @@ function _system_get_theme_data() {
     // Set defaults for theme info.
     $defaults = array(
       'regions' => array(
-        'left' => 'Left sidebar',
-        'right' => 'Right sidebar',
+        'sidebar_first' => 'First sidebar',
+        'sidebar_second' => 'Second sidebar',
         'content' => 'Content',
         'header' => 'Header',
         'footer' => 'Footer',
Index: themes/garland/page.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/page.tpl.php,v
retrieving revision 1.27
diff -u -p -r1.27 page.tpl.php
--- themes/garland/page.tpl.php	28 May 2009 16:44:07 -0000	1.27
+++ themes/garland/page.tpl.php	12 Jun 2009 08:39:22 -0000
@@ -36,10 +36,10 @@
         <?php if ($secondary_nav): print $secondary_nav; endif; ?>
       </div> <!-- /#header -->
 
-      <?php if ($left): ?>
-        <div id="sidebar-left" class="sidebar">
+      <?php if ($sidebar_first): ?>
+        <div id="sidebar-first" class="sidebar">
           <?php if ($search_box): ?><div class="block block-theme"><?php print $search_box ?></div><?php endif; ?>
-          <?php print $left ?>
+          <?php print $sidebar_first ?>
         </div>
       <?php endif; ?>
 
@@ -59,10 +59,10 @@
           <div id="footer"><?php print $footer ?></div>
       </div></div></div></div> <!-- /.left-corner, /.right-corner, /#squeeze, /#center -->
 
-      <?php if ($right): ?>
-        <div id="sidebar-right" class="sidebar">
-          <?php if (!$left && $search_box): ?><div class="block block-theme"><?php print $search_box ?></div><?php endif; ?>
-          <?php print $right ?>
+      <?php if ($sidebar_second): ?>
+        <div id="sidebar-second" class="sidebar">
+          <?php if (!$sidebar_first && $search_box): ?><div class="block block-theme"><?php print $search_box ?></div><?php endif; ?>
+          <?php print $sidebar_second ?>
         </div>
       <?php endif; ?>
 
Index: themes/garland/print.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/print.css,v
retrieving revision 1.7
diff -u -p -r1.7 print.css
--- themes/garland/print.css	25 Jun 2008 09:12:25 -0000	1.7
+++ themes/garland/print.css	12 Jun 2009 08:39:22 -0000
@@ -12,12 +12,12 @@ ul.main-menu, ul.secondary-menu,
   display: none;
 }
 
-body.two-sidebars, body.sidebar-left, body.sidebar-right, body {
+body.two-sidebars, body.sidebar-first, body.sidebar-second, body {
   width: 640px;
 }
 
-body.sidebar-left #center, body.sidebar-right #center, body.two-sidebars #center,
-body.sidebar-left #squeeze, body.sidebar-right #squeeze, body.two-sidebars #squeeze {
+body.sidebar-first #center, body.sidebar-second #center, body.two-sidebars #center,
+body.sidebar-first #squeeze, body.sidebar-second #squeeze, body.two-sidebars #squeeze {
   margin: 0;
 }
 
Index: themes/garland/style-rtl.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/style-rtl.css,v
retrieving revision 1.13
diff -u -p -r1.13 style-rtl.css
--- themes/garland/style-rtl.css	3 Jun 2009 06:58:57 -0000	1.13
+++ themes/garland/style-rtl.css	12 Jun 2009 08:39:22 -0000
@@ -86,11 +86,11 @@ dl dd {
   float: right;
 }
 
-#sidebar-left .block-region {
+#sidebar-first .block-region {
   margin: 0 0 0 15px;
 }
 
-#sidebar-right .block-region {
+#sidebar-second .block-region {
   margin: 0 15px 0px 0;
 }
 
@@ -270,7 +270,7 @@ ul.secondary li a, ul.secondary li.activ
   position: relative;
 }
 
-#sidebar-right{
+#sidebar-second {
   position: absolute;
   right: 0;
 }
Index: themes/garland/style.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/style.css,v
retrieving revision 1.57
diff -u -p -r1.57 style.css
--- themes/garland/style.css	31 May 2009 00:51:41 -0000	1.57
+++ themes/garland/style.css	12 Jun 2009 08:39:22 -0000
@@ -377,7 +377,7 @@ body.two-sidebars {
   min-width: 980px;
 }
 /* With 2 columns, require a minimum width of 800px. */
-body.sidebar-left, body.sidebar-right {
+body.sidebar-first, body.sidebar-second {
   min-width: 780px;
 }
 
@@ -388,10 +388,10 @@ body.sidebar-left, body.sidebar-right {
 }
 
 /* So we move the #center container over the sidebars to compensate */
-body.sidebar-left #center {
+body.sidebar-first #center {
   margin-left: -210px;
 }
-body.sidebar-right #center {
+body.sidebar-second #center {
   margin-right: -210px;
 }
 body.two-sidebars #center {
@@ -399,10 +399,10 @@ body.two-sidebars #center {
 }
 
 /* And add blanks left and right for the sidebars to fill */
-body.sidebar-left #squeeze {
+body.sidebar-first #squeeze {
   margin-left: 210px;
 }
-body.sidebar-right #squeeze {
+body.sidebar-second #squeeze {
   margin-right: 210px;
 }
 body.two-sidebars #squeeze {
@@ -422,11 +422,11 @@ body.two-sidebars #squeeze {
   margin: 0 0 1.5em 0;
 }
 
-#sidebar-left .block {
+#sidebar-first .block {
   padding: 0 15px 0 0px;
 }
 
-#sidebar-right .block {
+#sidebar-second .block {
   padding: 0 0px 0 15px;
 }
 
@@ -434,11 +434,11 @@ body.two-sidebars #squeeze {
   margin: 0.5em 0;
 }
 
-#sidebar-left .block-region {
+#sidebar-first .block-region {
   margin: 0 15px 0 0px; /* LTR */
 }
 
-#sidebar-right .block-region {
+#sidebar-second .block-region {
   margin: 0 0px 0 15px; /* LTR */
 }
 
@@ -486,11 +486,11 @@ body.two-sidebars #squeeze {
   z-index: 3;
 }
 
-body.sidebar-left #footer {
+body.sidebar-first #footer {
   margin-left: -210px;
 }
 
-body.sidebar-right #footer {
+body.sidebar-second #footer {
   margin-right: -210px;
 }
 
Index: themes/garland/minnelli/minnelli.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/minnelli/minnelli.css,v
retrieving revision 1.6
diff -u -p -r1.6 minnelli.css
--- themes/garland/minnelli/minnelli.css	28 Apr 2008 09:25:27 -0000	1.6
+++ themes/garland/minnelli/minnelli.css	12 Jun 2009 08:39:22 -0000
@@ -8,7 +8,7 @@ body.two-sidebars #wrapper #container {
   width: 980px;
 }
 
-body.sidebar-left #wrapper #container,
-body.sidebar-right #wrapper #container {
+body.sidebar-first #wrapper #container,
+body.sidebar-second #wrapper #container {
   width: 770px;
 }
Index: themes/stark/layout.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/stark/layout.css,v
retrieving revision 1.2
diff -u -p -r1.2 layout.css
--- themes/stark/layout.css	24 Feb 2009 17:50:22 -0000	1.2
+++ themes/stark/layout.css	12 Jun 2009 08:39:22 -0000
@@ -17,8 +17,8 @@
  */
 
 #content,
-#sidebar-left,
-#sidebar-right {
+#sidebar-first,
+#sidebar-second {
   float: left;
   display: inline;
   position: relative;
@@ -27,11 +27,11 @@
 #content {
   width: 100%;
 }
-body.sidebar-left #content {
+body.sidebar-first #content {
   width: 80%;
   left: 20%;
 }
-body.sidebar-right #content {
+body.sidebar-second #content {
   width: 80%;
 }
 body.two-sidebars #content {
@@ -39,16 +39,16 @@ body.two-sidebars #content {
   left: 20%;
 }
 
-#sidebar-left {
+#sidebar-first {
   width: 20%;
   left: -80%;
 }
 
-body.two-sidebars #sidebar-left {
+body.two-sidebars #sidebar-first {
   left: -60%;
 }
 
-#sidebar-right {
+#sidebar-second {
   float: right;
   width: 20%;
 }

Index: modules/system/page.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/system/page.tpl.php,v
retrieving revision 1.22
diff -u -p -r1.22 page.tpl.php
--- modules/system/page.tpl.php	28 May 2009 16:44:06 -0000	1.22
+++ modules/system/page.tpl.php	12 Jun 2009 08:39:21 -0000
@@ -46,10 +46,10 @@
  *   - node-type-[node type]: When viewing a single node, the type of that node.
  *     For example, if the node is a "Blog entry" it would result in "node-type-blog".
  *     Note that the machine name will often be in a short form of the human readable label.
  *   The following only apply with the default 'left' and 'right' block regions:
  *     - two-sidebars: When both sidebars have content.
  *     - no-sidebars: When no sidebar content exists.
  *     - one-sidebar and sidebar-left or sidebar-right: A combination of the two classes
  *       when only one of the two sidebars have content.
  *
  * Site identity:
@@ -77,8 +77,8 @@
  * - $help: Dynamic help text, mostly for admin pages.
  * - $content: The main content of the current Drupal page.
  * - $feed_icons: A string of all feed icons for the current page.
- * - $left: The HTML for the left sidebar.
- * - $right: The HTML for the right sidebar.
+ * - $sidebar_first: The HTML for the first sidebar.
+ * - $sidebar_second: The HTML for the second sidebar.
  * - $highlight: The HTML for the highlighted content region.
  *
  * Footer/closing data:
@@ -171,16 +171,16 @@
         <?php print $feed_icons; ?>
       </div></div> <!-- /.section, /#content -->
 
-      <?php if ($left): ?>
-        <div id="sidebar-left" class="column sidebar"><div class="section region">
-          <?php print $left; ?>
-        </div></div> <!-- /.section, /#sidebar-left -->
+      <?php if ($sidebar_first): ?>
+        <div id="sidebar-first" class="column sidebar"><div class="section region">
+          <?php print $sidebar_first; ?>
+        </div></div> <!-- /.section, /#sidebar-first -->
       <?php endif; ?>
 
-      <?php if ($right): ?>
-        <div id="sidebar-right" class="column sidebar"><div class="section region">
-          <?php print $right; ?>
-        </div></div> <!-- /.section, /#sidebar-right -->
+      <?php if ($sidebar_second): ?>
+        <div id="sidebar-second" class="column sidebar"><div class="section region">
+          <?php print $sidebar_second; ?>
+        </div></div> <!-- /.section, /#sidebar-second -->
       <?php endif; ?>
 
     </div></div> <!-- /#main, /#main-wrapper -->
@@ -46,10 +46,10 @@
  *     For example, if the node is a "Blog entry" it would result in "node-type-blog".
  *     Note that the machine name will often be in a short form of the human readable label.
- *   The following only apply with the default 'left' and 'right' block regions:
+ *   The following only apply with the default 'sidebar_first' and 'sidebar_second' block regions:
  *     - two-sidebars: When both sidebars have content.
  *     - no-sidebars: When no sidebar content exists.
@@ -46,10 +46,10 @@
  *     - two-sidebars: When both sidebars have content.
  *     - no-sidebars: When no sidebar content exists.
- *     - one-sidebar and sidebar-left or sidebar-right: A combination of the two classes
+ *     - one-sidebar and sidebar-first or sidebar-second: A combination of the two classes
  *       when only one of the two sidebars have content.
  *